@@ -2,33 +2,33 @@ package submarineragent
 
 import (
 	"context"
+	"embed"
 	"fmt"
-	"path/filepath"
 
 	"github.com/ghodss/yaml"
+	"github.com/open-cluster-management/submariner-addon/pkg/manifestwork"
 
-	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
-	addonclient "github.com/open-cluster-management/api/client/addon/clientset/versioned"
-	addoninformerv1alpha1 "github.com/open-cluster-management/api/client/addon/informers/externalversions/addon/v1alpha1"
-	addonlisterv1alpha1 "github.com/open-cluster-management/api/client/addon/listers/addon/v1alpha1"
-	clusterclient "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
-	clusterinformerv1 "github.com/open-cluster-management/api/client/cluster/informers/externalversions/cluster/v1"
-	clusterinformerv1alpha1 "github.com/open-cluster-management/api/client/cluster/informers/externalversions/cluster/v1alpha1"
-	clusterlisterv1 "github.com/open-cluster-management/api/client/cluster/listers/cluster/v1"
-	clusterlisterv1alpha1 "github.com/open-cluster-management/api/client/cluster/listers/cluster/v1alpha1"
-	workclient "github.com/open-cluster-management/api/client/work/clientset/versioned"
-	workinformer "github.com/open-cluster-management/api/client/work/informers/externalversions/work/v1"
-	worklister "github.com/open-cluster-management/api/client/work/listers/work/v1"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	workv1 "github.com/open-cluster-management/api/work/v1"
-	configv1alpha1 "github.com/stolostron/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
-	configclient "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
-	configinformer "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/informers/externalversions/submarinerconfig/v1alpha1"
-	configlister "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/listers/submarinerconfig/v1alpha1"
-	"github.com/stolostron/submariner-addon/pkg/cloud"
-	"github.com/stolostron/submariner-addon/pkg/helpers"
-	"github.com/stolostron/submariner-addon/pkg/hub/submarineragent/bindata"
-	brokerinfo "github.com/stolostron/submariner-addon/pkg/hub/submarinerbrokerinfo"
+	configv1alpha1 "github.com/open-cluster-management/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
+	configclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
+	configinformer "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/informers/externalversions/submarinerconfig/v1alpha1"
+	configlister "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/listers/submarinerconfig/v1alpha1"
+	"github.com/open-cluster-management/submariner-addon/pkg/cloud"
+	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
+	brokerinfo "github.com/open-cluster-management/submariner-addon/pkg/hub/submarinerbrokerinfo"
+	addonv1alpha1 "open-cluster-management.io/api/addon/v1alpha1"
+	addonclient "open-cluster-management.io/api/client/addon/clientset/versioned"
+	addoninformerv1alpha1 "open-cluster-management.io/api/client/addon/informers/externalversions/addon/v1alpha1"
+	addonlisterv1alpha1 "open-cluster-management.io/api/client/addon/listers/addon/v1alpha1"
+	clusterclient "open-cluster-management.io/api/client/cluster/clientset/versioned"
+	clusterinformerv1 "open-cluster-management.io/api/client/cluster/informers/externalversions/cluster/v1"
+	clusterinformerv1alpha1 "open-cluster-management.io/api/client/cluster/informers/externalversions/cluster/v1alpha1"
+	clusterlisterv1 "open-cluster-management.io/api/client/cluster/listers/cluster/v1"
+	clusterlisterv1alpha1 "open-cluster-management.io/api/client/cluster/listers/cluster/v1alpha1"
+	workclient "open-cluster-management.io/api/client/work/clientset/versioned"
+	workinformer "open-cluster-management.io/api/client/work/informers/externalversions/work/v1"
+	worklister "open-cluster-management.io/api/client/work/listers/work/v1"
+	clusterv1 "open-cluster-management.io/api/cluster/v1"
+	workv1 "open-cluster-management.io/api/work/v1"
 
 	"github.com/openshift/library-go/pkg/assets"
 	"github.com/openshift/library-go/pkg/controller/factory"
@@ -61,23 +61,26 @@ const (
 )
 
 var clusterRBACFiles = []string{
-	"manifests/agent/rbac/broker-cluster-serviceaccount.yaml",
-	"manifests/agent/rbac/broker-cluster-rolebinding.yaml",
+	"manifests/rbac/broker-cluster-serviceaccount.yaml",
+	"manifests/rbac/broker-cluster-rolebinding.yaml",
 }
 
-const agentRBACFile = "manifests/agent/rbac/operatorgroup-aggregate-clusterrole.yaml"
+const agentRBACFile = "manifests/rbac/operatorgroup-aggregate-clusterrole.yaml"
 
 var sccFiles = []string{
-	"manifests/agent/rbac/scc-aggregate-clusterrole.yaml",
-	"manifests/agent/rbac/submariner-agent-scc.yaml",
+	"manifests/rbac/scc-aggregate-clusterrole.yaml",
+	"manifests/rbac/submariner-agent-scc.yaml",
 }
 
 var operatorFiles = []string{
-	"manifests/agent/operator/submariner-operator-group.yaml",
-	"manifests/agent/operator/submariner-operator-subscription.yaml",
-	"manifests/agent/operator/submariner.io-submariners-cr.yaml",
+	"manifests/operator/submariner-operator-group.yaml",
+	"manifests/operator/submariner-operator-subscription.yaml",
+	"manifests/operator/submariner.io-submariners-cr.yaml",
 }
 
+//go:embed manifests
+var manifestFiles embed.FS
+
 type clusterRBACConfig struct {
 	ManagedClusterName        string
 	SubmarinerBrokerNamespace string
@@ -86,18 +89,19 @@ type clusterRBACConfig struct {
 // submarinerAgentController reconciles instances of ManagedCluster on the hub to deploy/remove
 // corresponding submariner agent manifestworks
 type submarinerAgentController struct {
-	kubeClient         kubernetes.Interface
-	dynamicClient      dynamic.Interface
-	clusterClient      clusterclient.Interface
-	manifestWorkClient workclient.Interface
-	configClient       configclient.Interface
-	addOnClient        addonclient.Interface
-	clusterLister      clusterlisterv1.ManagedClusterLister
-	clusterSetLister   clusterlisterv1alpha1.ManagedClusterSetLister
-	manifestWorkLister worklister.ManifestWorkLister
-	configLister       configlister.SubmarinerConfigLister
-	addOnLister        addonlisterv1alpha1.ManagedClusterAddOnLister
-	eventRecorder      events.Recorder
+	kubeClient           kubernetes.Interface
+	dynamicClient        dynamic.Interface
+	clusterClient        clusterclient.Interface
+	manifestWorkClient   workclient.Interface
+	configClient         configclient.Interface
+	addOnClient          addonclient.Interface
+	clusterLister        clusterlisterv1.ManagedClusterLister
+	clusterSetLister     clusterlisterv1alpha1.ManagedClusterSetLister
+	manifestWorkLister   worklister.ManifestWorkLister
+	configLister         configlister.SubmarinerConfigLister
+	addOnLister          addonlisterv1alpha1.ManagedClusterAddOnLister
+	cloudProviderFactory cloud.ProviderFactory
+	eventRecorder        events.Recorder
 }
 
 // NewSubmarinerAgentController returns a submarinerAgentController instance
@@ -113,20 +117,22 @@ func NewSubmarinerAgentController(
 	manifestWorkInformer workinformer.ManifestWorkInformer,
 	configInformer configinformer.SubmarinerConfigInformer,
 	addOnInformer addoninformerv1alpha1.ManagedClusterAddOnInformer,
+	cloudProviderFactory cloud.ProviderFactory,
 	recorder events.Recorder) factory.Controller {
 	c := &submarinerAgentController{
-		kubeClient:         kubeClient,
-		dynamicClient:      dynamicClient,
-		clusterClient:      clusterClient,
-		manifestWorkClient: manifestWorkClient,
-		configClient:       configClient,
-		addOnClient:        addOnClient,
-		clusterLister:      clusterInformer.Lister(),
-		clusterSetLister:   clusterSetInformer.Lister(),
-		manifestWorkLister: manifestWorkInformer.Lister(),
-		configLister:       configInformer.Lister(),
-		addOnLister:        addOnInformer.Lister(),
-		eventRecorder:      recorder.WithComponentSuffix("submariner-agent-controller"),
+		kubeClient:           kubeClient,
+		dynamicClient:        dynamicClient,
+		clusterClient:        clusterClient,
+		manifestWorkClient:   manifestWorkClient,
+		configClient:         configClient,
+		addOnClient:          addOnClient,
+		clusterLister:        clusterInformer.Lister(),
+		clusterSetLister:     clusterSetInformer.Lister(),
+		manifestWorkLister:   manifestWorkInformer.Lister(),
+		configLister:         configInformer.Lister(),
+		addOnLister:          addOnInformer.Lister(),
+		cloudProviderFactory: cloudProviderFactory,
+		eventRecorder:        recorder.WithComponentSuffix("submariner-agent-controller"),
 	}
 	return factory.New().
 		WithInformersQueueKeyFunc(func(obj runtime.Object) string {
@@ -341,51 +347,43 @@ func (c *submarinerAgentController) syncSubmarinerConfig(ctx context.Context,
 
 	// config is deleting, we remove its related resources
 	if !config.DeletionTimestamp.IsZero() {
-		if err := c.cleanUpSubmarinerClusterEnv(ctx, config); err != nil {
-			return err
+		if config.Status.ManagedClusterInfo.Platform != "GCP" {
+			if err := c.cleanUpSubmarinerClusterEnv(ctx, config); err != nil {
+				return err
+			}
 		}
 		return helpers.RemoveConfigFinalizer(ctx, c.configClient, config, submarinerConfigFinalizer)
+
 	}
 
 	if managedCluster == nil {
 		return nil
 	}
-	managedClusterInfo := helpers.GetManagedClusterInfo(managedCluster)
 
-	if config.Spec.CredentialsSecret == nil {
-		// no platform credentials, the cluster env is not requred to prepare, only update the manged cluster info
-		_, _, err := helpers.UpdateSubmarinerConfigStatus(
-			c.configClient,
-			config.Namespace, config.Name,
-			helpers.UpdateSubmarinerConfigStatusFn(metav1.Condition{
-				Type:    configv1alpha1.SubmarinerConfigConditionApplied,
-				Status:  metav1.ConditionTrue,
-				Reason:  "SubmarinerConfigApplied",
-				Message: "SubmarinerConfig was applied",
-			}, managedClusterInfo),
-		)
-		return err
-	}
+	managedClusterInfo := helpers.GetManagedClusterInfo(managedCluster)
 
 	// prepare submariner cluster environment
 	errs := []error{}
-	cloudProvider, preparedErr := cloud.GetCloudProvider(c.kubeClient, c.manifestWorkClient, c.eventRecorder, managedClusterInfo, config)
-	if preparedErr == nil {
-		preparedErr = cloudProvider.PrepareSubmarinerClusterEnv()
-	}
+	var condition *metav1.Condition
+	if managedClusterInfo.Platform != "GCP" {
+		cloudProvider, preparedErr := c.cloudProviderFactory.Get(managedClusterInfo, config, c.eventRecorder)
+		if preparedErr == nil {
+			preparedErr = cloudProvider.PrepareSubmarinerClusterEnv()
+		}
 
-	condition := metav1.Condition{
-		Type:    configv1alpha1.SubmarinerConfigConditionEnvPrepared,
-		Status:  metav1.ConditionTrue,
-		Reason:  "SubmarinerClusterEnvPrepared",
-		Message: "Submariner cluster environment was prepared",
-	}
+		condition = &metav1.Condition{
+			Type:    configv1alpha1.SubmarinerConfigConditionEnvPrepared,
+			Status:  metav1.ConditionTrue,
+			Reason:  "SubmarinerClusterEnvPrepared",
+			Message: "Submariner cluster environment was prepared",
+		}
 
-	if preparedErr != nil {
-		condition.Status = metav1.ConditionFalse
-		condition.Reason = "SubmarinerClusterEnvPreparationFailed"
-		condition.Message = fmt.Sprintf("Failed to prepare submariner cluster environment: %v", preparedErr)
-		errs = append(errs, preparedErr)
+		if preparedErr != nil {
+			condition.Status = metav1.ConditionFalse
+			condition.Reason = "SubmarinerClusterEnvPreparationFailed"
+			condition.Message = fmt.Sprintf("Failed to prepare submariner cluster environment: %v", preparedErr)
+			errs = append(errs, preparedErr)
+		}
 	}
 
 	_, updated, updatedErr := helpers.UpdateSubmarinerConfigStatus(
@@ -393,11 +391,14 @@ func (c *submarinerAgentController) syncSubmarinerConfig(ctx context.Context,
 		config.Namespace, config.Name,
 		helpers.UpdateSubmarinerConfigStatusFn(condition, managedClusterInfo),
 	)
+
 	if updatedErr != nil {
 		errs = append(errs, updatedErr)
 	}
+
 	if updated {
-		c.eventRecorder.Eventf("SubmarinerClusterEnvPrepared", "submariner cluster environment was prepared for manged cluster %s", config.Namespace)
+		c.eventRecorder.Eventf("SubmarinerClusterEnvPrepared",
+			"submariner cluster environment was prepared for managed cluster %s", config.Namespace)
 	}
 
 	return operatorhelpers.NewMultiLineAggregate(errs)
@@ -448,15 +449,15 @@ func (c *submarinerAgentController) deploySubmarinerAgent(
 	}
 
 	// create submariner broker info with submariner config
-	brokerInfo, err := brokerinfo.NewSubmarinerBrokerInfo(
+	brokerInfo, err := brokerinfo.Get(
 		c.kubeClient,
 		c.dynamicClient,
 		c.configClient,
 		c.eventRecorder,
-		managedCluster,
+		managedCluster.Name,
 		brokerNamespace,
 		submarinerConfig,
-		managedClusterAddOn,
+		managedClusterAddOn.Spec.InstallNamespace,
 	)
 	if err != nil {
 		return fmt.Errorf("failed to create submariner brokerInfo of cluster %v : %v", managedCluster.Name, err)
@@ -467,7 +468,7 @@ func (c *submarinerAgentController) deploySubmarinerAgent(
 	if err != nil {
 		return err
 	}
-	if err := helpers.ApplyManifestWork(ctx, c.manifestWorkClient, operatorManifestWork, c.eventRecorder); err != nil {
+	if err := manifestwork.Apply(ctx, c.manifestWorkClient, operatorManifestWork, c.eventRecorder); err != nil {
 		return err
 	}
 
@@ -505,7 +506,11 @@ func (c *submarinerAgentController) applyClusterRBACFiles(brokerNamespace, manag
 		clientHolder,
 		c.eventRecorder,
 		func(name string) ([]byte, error) {
-			return assets.MustCreateAssetFromTemplate(name, bindata.MustAsset(filepath.Join("", name)), config).Data, nil
+			template, err := manifestFiles.ReadFile(name)
+			if err != nil {
+				return nil, err
+			}
+			return assets.MustCreateAssetFromTemplate(name, template, config).Data, nil
 		},
 		clusterRBACFiles...,
 	)
@@ -545,31 +550,32 @@ func (c *submarinerAgentController) removeClusterRBACFiles(ctx context.Context,
 		c.kubeClient,
 		c.eventRecorder,
 		func(name string) ([]byte, error) {
-			return assets.MustCreateAssetFromTemplate(name, bindata.MustAsset(filepath.Join("", name)), config).Data, nil
+			template, err := manifestFiles.ReadFile(name)
+			if err != nil {
+				return nil, err
+			}
+			return assets.MustCreateAssetFromTemplate(name, template, config).Data, nil
 		},
 		clusterRBACFiles...,
 	)
 }
 
 func (c *submarinerAgentController) cleanUpSubmarinerClusterEnv(ctx context.Context, config *configv1alpha1.SubmarinerConfig) error {
-	// no platform credentials, the submariner cluster environment is not prepared
-	if config.Spec.CredentialsSecret == nil {
+	cloudProvider, err := c.cloudProviderFactory.Get(config.Status.ManagedClusterInfo, config, c.eventRecorder)
+	if err != nil {
+		//TODO handle the error gracefully in the future
+		c.eventRecorder.Warningf("CleanUpSubmarinerClusterEnvFailed", "failed to get cloud provider: %v", err)
 		return nil
 	}
 
-	managedClusterInfo := config.Status.ManagedClusterInfo
-	cloudProvider, err := cloud.GetCloudProvider(c.kubeClient, c.manifestWorkClient, c.eventRecorder, managedClusterInfo, config)
-	if err != nil {
-		//TODO handle the error gracefully in the future
-		c.eventRecorder.Warningf("CleanUpSubmarinerClusterEnvFailed", "failed to create cloud provider: %v", err)
-		return nil
-	}
 	if err := cloudProvider.CleanUpSubmarinerClusterEnv(); err != nil {
 		//TODO handle the error gracefully in the future
 		c.eventRecorder.Warningf("CleanUpSubmarinerClusterEnvFailed", "failed to clean up cloud environment: %v", err)
 		return nil
 	}
-	c.eventRecorder.Eventf("SubmarinerClusterEnvDeleted", "the managed cluster %s submariner cluster environment is deleted", managedClusterInfo.ClusterName)
+
+	c.eventRecorder.Eventf("SubmarinerClusterEnvDeleted", "the managed cluster %s submariner cluster environment is deleted",
+		config.Status.ManagedClusterInfo.ClusterName)
 	return nil
 }
 
@@ -582,7 +588,11 @@ func getManifestWork(managedCluster *clusterv1.ManagedCluster, config interface{
 
 	manifests := []workv1.Manifest{}
 	for _, file := range files {
-		yamlData := assets.MustCreateAssetFromTemplate(file, bindata.MustAsset(filepath.Join("", file)), config).Data
+		template, err := manifestFiles.ReadFile(file)
+		if err != nil {
+			return nil, err
+		}
+		yamlData := assets.MustCreateAssetFromTemplate(file, template, config).Data
 		jsonData, err := yaml.YAMLToJSON(yamlData)
 		if err != nil {
 			return nil, err
