@@ -6,22 +6,22 @@ import (
 	"testing"
 	"time"
 
-	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
-	addonfake "github.com/open-cluster-management/api/client/addon/clientset/versioned/fake"
-	addoninformers "github.com/open-cluster-management/api/client/addon/informers/externalversions"
-	clusterfake "github.com/open-cluster-management/api/client/cluster/clientset/versioned/fake"
-	fakeclusterclient "github.com/open-cluster-management/api/client/cluster/clientset/versioned/fake"
-	clusterinformers "github.com/open-cluster-management/api/client/cluster/informers/externalversions"
-	fakeworkclient "github.com/open-cluster-management/api/client/work/clientset/versioned/fake"
-	workfake "github.com/open-cluster-management/api/client/work/clientset/versioned/fake"
-	workinformers "github.com/open-cluster-management/api/client/work/informers/externalversions"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	workv1 "github.com/open-cluster-management/api/work/v1"
-	configv1alpha1 "github.com/stolostron/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
-	fakeconfigclient "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/clientset/versioned/fake"
-	configinformers "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
-	testinghelpers "github.com/stolostron/submariner-addon/pkg/helpers/testing"
+	configv1alpha1 "github.com/open-cluster-management/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
+	fakeconfigclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned/fake"
+	configinformers "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
+	testinghelpers "github.com/open-cluster-management/submariner-addon/pkg/helpers/testing"
+	addonv1alpha1 "open-cluster-management.io/api/addon/v1alpha1"
+	addonfake "open-cluster-management.io/api/client/addon/clientset/versioned/fake"
+	addoninformers "open-cluster-management.io/api/client/addon/informers/externalversions"
+	clusterfake "open-cluster-management.io/api/client/cluster/clientset/versioned/fake"
+	fakeclusterclient "open-cluster-management.io/api/client/cluster/clientset/versioned/fake"
+	clusterinformers "open-cluster-management.io/api/client/cluster/informers/externalversions"
+	fakeworkclient "open-cluster-management.io/api/client/work/clientset/versioned/fake"
+	workfake "open-cluster-management.io/api/client/work/clientset/versioned/fake"
+	workinformers "open-cluster-management.io/api/client/work/informers/externalversions"
+	clusterv1 "open-cluster-management.io/api/cluster/v1"
+	clusterv1alpha1 "open-cluster-management.io/api/cluster/v1alpha1"
+	workv1 "open-cluster-management.io/api/work/v1"
 
 	"github.com/openshift/library-go/pkg/operator/events/eventstesting"
 
@@ -486,59 +486,6 @@ func TestSyncSubmarinerConfig(t *testing.T) {
 				testinghelpers.AssertNoActions(t, configActions)
 			},
 		},
-		{
-			name:     "unsupported cluster vendor",
-			queueKey: "cluster1/submariner",
-			configs: []runtime.Object{
-				&configv1alpha1.SubmarinerConfig{
-					ObjectMeta: metav1.ObjectMeta{
-						Name:       "submariner",
-						Namespace:  "cluster1",
-						Finalizers: []string{"submarineraddon.open-cluster-management.io/config-cleanup"},
-					},
-					Spec: configv1alpha1.SubmarinerConfigSpec{
-						CredentialsSecret: &v1.LocalObjectReference{
-							Name: "test",
-						},
-					},
-				},
-			},
-			clusters: []runtime.Object{
-				&clusterv1.ManagedCluster{
-					ObjectMeta: metav1.ObjectMeta{
-						Name:   "cluster1",
-						Labels: map[string]string{"vendor": "unsupported"},
-					},
-				},
-			},
-			expectedErr: true,
-			validateActions: func(t *testing.T, configActions []clienttesting.Action) {
-				testinghelpers.AssertActions(t, configActions, "get", "update")
-			},
-		},
-		{
-			name:     "delete a submariner config without credentials secret",
-			queueKey: "cluster1/submariner",
-			configs: []runtime.Object{
-				&configv1alpha1.SubmarinerConfig{
-					ObjectMeta: metav1.ObjectMeta{
-						Name:              "submariner",
-						Namespace:         "cluster1",
-						DeletionTimestamp: &now,
-						Finalizers:        []string{"submarineraddon.open-cluster-management.io/config-cleanup"},
-					},
-				},
-			},
-			clusters: []runtime.Object{},
-			validateActions: func(t *testing.T, configActions []clienttesting.Action) {
-				testinghelpers.AssertActions(t, configActions, "update")
-				updatedObj := configActions[0].(clienttesting.UpdateActionImpl).Object
-				config := updatedObj.(*configv1alpha1.SubmarinerConfig)
-				if len(config.Finalizers) != 0 {
-					t.Errorf("unexpect size of finalizers")
-				}
-			},
-		},
 		{
 			name:     "delete a submariner config",
 			queueKey: "cluster1/submariner",
@@ -550,9 +497,9 @@ func TestSyncSubmarinerConfig(t *testing.T) {
 						DeletionTimestamp: &now,
 						Finalizers:        []string{"submarineraddon.open-cluster-management.io/config-cleanup"},
 					},
-					Spec: configv1alpha1.SubmarinerConfigSpec{
-						CredentialsSecret: &v1.LocalObjectReference{
-							Name: "aws-credentials-secret",
+					Status: configv1alpha1.SubmarinerConfigStatus{
+						ManagedClusterInfo: configv1alpha1.ManagedClusterInfo{
+							Platform: "GCP",
 						},
 					},
 				},
