@@ -5,15 +5,11 @@ import (
 	"fmt"
 	"strings"
 
-	addonclient "github.com/open-cluster-management/api/client/addon/clientset/versioned"
-	addoninformerv1alpha1 "github.com/open-cluster-management/api/client/addon/informers/externalversions/addon/v1alpha1"
-	addonlisterv1alpha1 "github.com/open-cluster-management/api/client/addon/listers/addon/v1alpha1"
-	"github.com/stolostron/submariner-addon/pkg/helpers"
-
+	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
 	"github.com/openshift/library-go/pkg/controller/factory"
 	"github.com/openshift/library-go/pkg/operator/events"
-
 	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
+	addonclient "open-cluster-management.io/api/client/addon/clientset/versioned"
 
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -37,7 +33,6 @@ const submarinerAgentDegraded = "SubmarinerAgentDegraded"
 // on the managed cluster and reports the status to the submariner-addon on the hub cluster
 type deploymentStatusController struct {
 	addOnClient        addonclient.Interface
-	addOnLister        addonlisterv1alpha1.ManagedClusterAddOnLister
 	daemonSetLister    appsv1lister.DaemonSetLister
 	deploymentLister   appsv1lister.DeploymentLister
 	subscriptionLister cache.GenericLister
@@ -46,18 +41,11 @@ type deploymentStatusController struct {
 }
 
 // NewDeploymentStatusController returns an instance of deploymentStatusController
-func NewDeploymentStatusController(
-	clusterName string,
-	installationNamespace string,
-	addOnClient addonclient.Interface,
-	addOnInformer addoninformerv1alpha1.ManagedClusterAddOnInformer,
-	daemonsetInformer appsv1informers.DaemonSetInformer,
-	deploymentInformer appsv1informers.DeploymentInformer,
-	subscriptionInformer informers.GenericInformer,
-	recorder events.Recorder) factory.Controller {
+func NewDeploymentStatusController(clusterName string, installationNamespace string, addOnClient addonclient.Interface,
+	daemonsetInformer appsv1informers.DaemonSetInformer, deploymentInformer appsv1informers.DeploymentInformer,
+	subscriptionInformer informers.GenericInformer, recorder events.Recorder) factory.Controller {
 	c := &deploymentStatusController{
 		addOnClient:        addOnClient,
-		addOnLister:        addOnInformer.Lister(),
 		daemonSetLister:    daemonsetInformer.Lister(),
 		deploymentLister:   deploymentInformer.Lister(),
 		subscriptionLister: subscriptionInformer.Lister(),
@@ -72,15 +60,6 @@ func NewDeploymentStatusController(
 }
 
 func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.SyncContext) error {
-	addOn, err := c.addOnLister.ManagedClusterAddOns(c.clusterName).Get(helpers.SubmarinerAddOnName)
-	if errors.IsNotFound(err) {
-		// addon is not found, could be deleted, ignore it.
-		return nil
-	}
-	if err != nil {
-		return err
-	}
-
 	degradedConditionReasons := []string{}
 	degradedConditionMessages := []string{}
 
@@ -106,7 +85,7 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 	if len(sub.Status.InstalledCSV) == 0 {
 		startingCSV := sub.Spec.StartingCSV
 		if len(startingCSV) == 0 {
-			startingCSV = "defualt"
+			startingCSV = "default"
 		}
 
 		channel := sub.Spec.Channel
@@ -114,7 +93,7 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 			channel = "default"
 		}
 
-		degradedConditionReasons = append(degradedConditionReasons, "OperatorNotDeployed")
+		degradedConditionReasons = append(degradedConditionReasons, "CSVNotInstalled")
 		degradedConditionMessages = append(degradedConditionMessages,
 			fmt.Sprintf("The submariner-operator CSV (%s) is not installed from channel (%s) in catalog source (%s/%s)",
 				startingCSV, channel, sub.Spec.CatalogSourceNamespace, sub.Spec.CatalogSource))
@@ -123,12 +102,12 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 	operator, err := c.deploymentLister.Deployments(c.namespace).Get(operatorName)
 	switch {
 	case errors.IsNotFound(err):
-		degradedConditionReasons = append(degradedConditionReasons, "OperatorNotDeployed")
-		degradedConditionMessages = append(degradedConditionMessages, "The submariner-operator is not found")
+		degradedConditionReasons = append(degradedConditionReasons, "NoOperatorDeployment")
+		degradedConditionMessages = append(degradedConditionMessages, "The submariner operator deployment does not exist")
 	case err == nil:
 		if operator.Status.AvailableReplicas == 0 {
-			degradedConditionReasons = append(degradedConditionReasons, "OperatorDegraded")
-			degradedConditionMessages = append(degradedConditionMessages, "There is no available submariner-operator")
+			degradedConditionReasons = append(degradedConditionReasons, "NoOperatorAvailable")
+			degradedConditionMessages = append(degradedConditionMessages, "There is no submariner operator replica available")
 		}
 	case err != nil:
 		return err
@@ -137,16 +116,16 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 	gateways, err := c.daemonSetLister.DaemonSets(c.namespace).Get(gatewayName)
 	switch {
 	case errors.IsNotFound(err):
-		degradedConditionReasons = append(degradedConditionReasons, "GatewaysNotDeployed")
-		degradedConditionMessages = append(degradedConditionMessages, "The gateways are not found")
+		degradedConditionReasons = append(degradedConditionReasons, "NoGatewayDaemonSet")
+		degradedConditionMessages = append(degradedConditionMessages, "The gateway daemon set does not exist")
 	case err == nil:
 		if gateways.Status.DesiredNumberScheduled == 0 {
-			degradedConditionReasons = append(degradedConditionReasons, "GatewaysDegraded")
+			degradedConditionReasons = append(degradedConditionReasons, "NoScheduledGateways")
 			degradedConditionMessages = append(degradedConditionMessages, "There are no nodes to run the gateways")
 		}
 
 		if gateways.Status.NumberUnavailable != 0 {
-			degradedConditionReasons = append(degradedConditionReasons, "GatewaysDegraded")
+			degradedConditionReasons = append(degradedConditionReasons, "GatewaysUnavailable")
 			degradedConditionMessages = append(degradedConditionMessages,
 				fmt.Sprintf("There are %d unavailable gateways", gateways.Status.NumberUnavailable))
 		}
@@ -157,11 +136,11 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 	routeAgent, err := c.daemonSetLister.DaemonSets(c.namespace).Get(routeAgentName)
 	switch {
 	case errors.IsNotFound(err):
-		degradedConditionReasons = append(degradedConditionReasons, "RouteAgentsNotDeployed")
+		degradedConditionReasons = append(degradedConditionReasons, "NoRouteAgentDaemonSet")
 		degradedConditionMessages = append(degradedConditionMessages, "The route agents are not found")
 	case err == nil:
 		if routeAgent.Status.NumberUnavailable != 0 {
-			degradedConditionReasons = append(degradedConditionReasons, "RouteAgentsDegraded")
+			degradedConditionReasons = append(degradedConditionReasons, "RouteAgentsUnavailable")
 			degradedConditionMessages = append(degradedConditionMessages,
 				fmt.Sprintf("There are %d unavailable route agents", routeAgent.Status.NumberUnavailable))
 		}
@@ -185,18 +164,15 @@ func (c *deploymentStatusController) sync(ctx context.Context, syncCtx factory.S
 	}
 
 	// check submariner agent status and update submariner-addon status on the hub cluster
-	_, updated, err := helpers.UpdateManagedClusterAddOnStatus(
-		ctx,
-		c.addOnClient,
-		c.clusterName,
-		addOn.Name,
-		helpers.UpdateManagedClusterAddOnStatusFn(submarinerAgentCondtion),
-	)
+	updatedStatus, updated, err := helpers.UpdateManagedClusterAddOnStatus(ctx, c.addOnClient, c.clusterName,
+		helpers.UpdateManagedClusterAddOnStatusFn(submarinerAgentCondtion))
 	if err != nil {
 		return err
 	}
+
 	if updated {
-		syncCtx.Recorder().Eventf("ManagedClusterAddOnStatusUpdated", "update managed cluster addon %q status with submariner agent status", addOn.Name)
+		syncCtx.Recorder().Eventf("ManagedClusterAddOnStatusUpdated", "Updated status conditions:  %#v",
+			updatedStatus.Conditions)
 	}
 
 	return nil
