@@ -80,10 +80,10 @@ function deploy_hub() {
 
     export KUBECONFIG=${kubeconfig_dir}/kubeconfig
     echo "Deploy hub on cluster ${cluster} ..."
-    # delploy operator
+    # deploy operator
     kubectl apply -k ${deploy_dir}/config/manifests
 
-    # delploy cluster managers
+    # deploy cluster managers
     kubectl apply -k ${deploy_dir}/config/samples
 
     # deploy the acm_submariner
@@ -95,6 +95,10 @@ function deploy_hub() {
     mkdir -p ${submariner_deploy_dir}
     cp -r deploy/* ${submariner_deploy_dir}
 
+    # Set submariner-addon imagePullPolicy to IfNotPresent
+    sed -i -- '/image: quay.io*/a\        imagePullPolicy: IfNotPresent' ${submariner_deploy_dir}/config/operator/operator.yaml
+
+
     # add master apiserver to submariner-addon deployment
     cat <<EOF >> ${submariner_deployment}
           - name: BROKER_API_SERVER
@@ -117,10 +121,10 @@ function deploy_klusterlet() {
 
     export KUBECONFIG=${kubeconfig_dir}/kubeconfig
     echo "Deploy klusterlet on cluster ${cluster} ..."
-    # delploy operator
+    # deploy operator
     kubectl apply -k ${deploy_dir}/config/manifests
 
-    # delploy klusterlet
+    # deploy klusterlet
     kubectl create namespace open-cluster-management-agent
     kubectl -n open-cluster-management-agent create secret generic bootstrap-hub-kubeconfig --from-file=${hub_kubeconfig}
     cat << EOF | kubectl apply -f -
@@ -129,8 +133,8 @@ kind: Klusterlet
 metadata:
   name: klusterlet
 spec:
-  registrationImagePullSpec: quay.io/stolostron/registration
-  workImagePullSpec: quay.io/stolostron/work
+  registrationImagePullSpec: quay.io/open-cluster-management/registration
+  workImagePullSpec: quay.io/open-cluster-management/work
   clusterName: ${cluster}
   namespace: open-cluster-management-agent
   externalServerURLs:
@@ -155,17 +159,17 @@ function accept_managed_cluster() {
     export KUBECONFIG=${hub_kubeconfig}
     # try to find the managed cluster
     times=0
-    for i in {0..60};
+    for i in {0..120};
     do
         kubectl get managedclusters $cluster >/dev/null 2>&1
         if [ 0 -eq $? ]; then
             break
         fi
-        sleep 1
+        sleep 2
         times=$(($times+1))
     done
-    if [ $times -ge 60 ]; then
-        echo "Unabel to find managed cluster $cluster within 1 min"
+    if [ $times -ge 120 ]; then
+        echo "Unable to find managed cluster $cluster within 4 min"
         return 2
     fi
 
@@ -200,13 +204,36 @@ spec:
     source: operatorhubio-catalog
     sourceNamespace: olm
 EOF
+
+    submrepo="quay.io/submariner"
+    submver="0.9.1"
+    kubectl patch submarinerconfigs submariner -n ${cluster} --type "json" -p '[
+{"op":"add","path":"/spec/imagePullSpecs/submarinerImagePullSpec","value":"'${submrepo}'/submariner-gateway:'${submver}'"},
+{"op":"add","path":"/spec/imagePullSpecs/submarinerRouteAgentImagePullSpec","value":"'${submrepo}'/submariner-route-agent:'${submver}'"},
+{"op":"add","path":"/spec/imagePullSpecs/lighthouseAgentImagePullSpec","value":"'${submrepo}'/lighthouse-agent:'${submver}'"},
+{"op":"add","path":"/spec/imagePullSpecs/lighthouseCoreDNSImagePullSpec","value":"'${submrepo}'/lighthouse-coredns:'${submver}'"},
+{"op":"add","path":"/spec/NATTEnable","value":false}]'
+
 }
 
+function validate_kubectl_version() {
+    majorVersion=$(kubectl version --short --client | cut -d: -f2 | cut -d. -f1)
+    minorVersion=$(kubectl version --short --client | cut -d: -f2 | cut -d. -f2)
+    if [ $majorVersion != "v1" ] || [ $minorVersion -lt 19 ]
+    then
+	    echo "Please update your kubectl version to v1.19 (or above)"
+	    exit 1
+    fi
+}
+
+validate_kubectl_version
+
 ### main ###
 work_dir="$(pwd)/_output"
 rm -rf ${work_dir}
 mkdir -p ${work_dir}
 
+
 # prepare clusters
 i=1
 for cluster in "${clusters[@]}";
@@ -223,13 +250,13 @@ done
 
 # downlaod registration-operator
 registration_operator_dir="${work_dir}/registration-operator"
-git clone --depth 1 --branch release-2.2 https://github.com/stolostron/registration-operator.git ${registration_operator_dir}
+git clone --depth 1 --branch release-2.2 https://github.com/open-cluster-management/registration-operator.git ${registration_operator_dir}
 
 # the first cluster is hub cluster
 hub="${clusters[0]}"
 
 # load submariner-addon image from local
-kind load --name="${hub}" docker-image quay.io/stolostron/submariner-addon:latest
+kind load --name="${hub}" docker-image quay.io/open-cluster-management/submariner-addon:latest
 
 # deploy hub
 deploy_hub ${hub}
